@@ -2,11 +2,11 @@ use 5.14.0;
 use strict;
 use warnings;
 
-package Dist::Zilla::Role::Author::CSSON::GithubActions;
+package Dist::Zilla::Plugin::Author::CSSON::GithubActions;
 
 # ABSTRACT: Ease creation of common Github Actions workflows
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.0104';
+our $VERSION = '0.0105';
 
 __END__
 
@@ -16,7 +16,7 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Role::Author::CSSON::GithubActions - Ease creation of common Github Actions workflows
+Dist::Zilla::Plugin::Author::CSSON::GithubActions - Ease creation of common Github Actions workflows
 
 
 
@@ -24,8 +24,8 @@ Dist::Zilla::Role::Author::CSSON::GithubActions - Ease creation of common Github
 
 <p>
 <img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
-<a href="http://cpants.cpanauthors.org/release/CSSON/Dist-Zilla-Plugin-Author-CSSON-GithubActions-0.0104"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/Dist-Zilla-Plugin-Author-CSSON-GithubActions/0.0104" alt="Distribution kwalitee" /></a>
-<a href="http://matrix.cpantesters.org/?dist=Dist-Zilla-Plugin-Author-CSSON-GithubActions%200.0104"><img src="http://badgedepot.code301.com/badge/cpantesters/Dist-Zilla-Plugin-Author-CSSON-GithubActions/0.0104" alt="CPAN Testers result" /></a>
+<a href="http://cpants.cpanauthors.org/release/CSSON/Dist-Zilla-Plugin-Author-CSSON-GithubActions-0.0105"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/Dist-Zilla-Plugin-Author-CSSON-GithubActions/0.0105" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Dist-Zilla-Plugin-Author-CSSON-GithubActions%200.0105"><img src="http://badgedepot.code301.com/badge/cpantesters/Dist-Zilla-Plugin-Author-CSSON-GithubActions/0.0105" alt="CPAN Testers result" /></a>
 <img src="https://img.shields.io/badge/coverage-88.8%-orange.svg" alt="coverage 88.8%" />
 </p>
 
@@ -33,7 +33,7 @@ Dist::Zilla::Role::Author::CSSON::GithubActions - Ease creation of common Github
 
 =head1 VERSION
 
-Version 0.0104, released 2020-12-26.
+Version 0.0105, released 2020-12-26.
 
 =head1 SYNOPSIS
 
